@@ -346,7 +346,7 @@ def getsize(path):
         # FindFilesW instead
         finddata = win32file.FindFilesW(path)
         if finddata == []:
-            # FindFilesW doesn't work for directories, so fallback to getsize()
+            # FindFilesW doesn't work for directories, so fall back to getsize()
             return os.path.getsize(path)
         else:
             size = (finddata[0][4] * (0xffffffff + 1)) + finddata[0][5]
@@ -376,7 +376,7 @@ def globex(pathname, regex):
 
 def guess_overwrite_paths():
     """Guess which partitions to overwrite (to hide deleted files)"""
-    # In case overwritting leaves large files, placing them in
+    # In case overwriting leaves large files, placing them in
     # ~/.config makes it easy to find them and clean them.
     ret = []
     if 'posix' == os.name:
@@ -387,14 +387,24 @@ def guess_overwrite_paths():
         if not same_partition(home, '/tmp/'):
             ret.append('/tmp')
     elif 'nt' == os.name:
-        localtmp = dirname = os.path.expandvars(
-            "$USERPROFILE\\Local Settings\\Temp\\")
+        localtmp = os.path.expandvars('$TMP')
+        if not os.path.exists(localtmp):
+            print 'ERROR: %TMP% does not exist:', localtmp
+            localtmp = None
+        else:
+            from win32file import GetLongPathName
+            localtmp = GetLongPathName(localtmp)
         from Windows import get_fixed_drives
         for drive in get_fixed_drives():
-            if same_partition(localtmp, drive):
-                ret.append(localtmp)
-            else:
-                ret.append(drive)
+            try:
+                if localtmp and same_partition(localtmp, drive):
+                    ret.append(localtmp)
+                else:
+                    ret.append(drive)
+            except Exception, e:
+                # see https://github.com/az0/bleachbit/issues/27
+                # https://bugs.launchpad.net/bleachbit/+bug/1372179
+                print 'ERROR in same_partition(%s, %s): %s' % (localtmp, drive, e)
     else:
         NotImplementedError('Unsupported OS in guess_overwrite_paths')
     return ret
