@@ -92,9 +92,9 @@ class TreeInfoModel:
             c_name = backends[key].get_name()
             c_id = backends[key].get_id()
             c_value = options.get_tree(c_id, None)
-            if not c_value and backends[key].auto_hide():
-                # hide irrelevant cleaner (e.g., the application is not
-                # detected)
+            if not c_value and options.get('auto_hide') \
+                and backends[key].auto_hide():
+                print "info: automatically hiding cleaner '%s'" % (c_id)
                 continue
             parent = self.tree_store.append(None, (c_name, c_value, c_id))
             for (o_id, o_name) in backends[key].get_options():
@@ -440,7 +440,7 @@ class GUI:
 
     def cb_preferences_dialog(self, action):
         """Callback for preferences dialog"""
-        pref = PreferencesDialog(self.window)
+        pref = PreferencesDialog(self.window, self.cb_refresh_operations)
         pref.run()
 
     def cb_refresh_operations(self):
@@ -778,7 +778,7 @@ class GUI:
             self.shred_paths(shred_paths)
             return
         if options.get("first_start") and 'posix' == os.name:
-            pref = PreferencesDialog(self.window)
+            pref = PreferencesDialog(self.window, self.cb_refresh_operations)
             pref.run()
             options.set('first_start', False)
         if online_update_notification_enabled and options.get("check_online_updates"):
@@ -794,6 +794,8 @@ class GUI:
                 print dir(e)
                 self.append_text(
                     _("Error loading the SQLite module: the antivirus software may be blocking it."), 'error')
+        if 'posix' == os.name and os.path.expanduser('~') == '/root':
+            self.append_text(_('You are running BleachBit with administrative privileges for cleaning shared parts of the system, and references to the user profile folder will clean only the root account.'))
 
 
 if __name__ == '__main__':
