@@ -106,13 +106,14 @@ def delete_chrome_favicons(path):
     ver = __get_chrome_history(path)
     cmds = ""
 
-    if ver in [4, 20, 22, 23, 25, 26, 28]:
+    if ver in [4, 20, 22, 23, 25, 26, 28, 29]:
         # Version 4 includes Chromium 12
         # Version 20 includes Chromium 14, Google Chrome 15, Google Chrome 19
         # Version 22 includes Google Chrome 20
         # Version 25 is Google Chrome 26
         # Version 26 is Google Chrome 29
         # Version 28 is Google Chrome 30
+        # Version 29 is Google Chrome 37
 
         # icon_mapping
         cols = ('page_url',)
